#!/bin/bash
#
# Given Parameters:
# $1 = update image
# $2 = the folder where this script is
# $3 = the current active partition

echo post update script called

####
# Remove old ntpd workaround
####
rm -f /etc2/.ntpWorkaround

####
# Use real files instead of softlinks for the dhcpcd.conf file
# Make use of a real soft factory reset here
####
[ -L /etc2/dhcpcd.conf ] && rm /etc2/dhcpcd.conf
rm -f /etc2/dhcpcd.conf.*
rm -f /etc2/dhcpcd.duid

rm -f /etc2/group
rm -f /etc2/shadow
rm -f /etc2/gshadow
rm -f /etc2/passwd
rm -f /etc2/lighttpd/lighttpd.conf

#BNPROD-2390
[ -h /mnt/free/www-upload ] && rm -f /mnt/free/www-upload

#BNPROD-1050
rm -f /etc2/sysctl.conf

# Replace the old snmpd.conf, if empty
#shellcheck disable=SC2015
# Just don't complain, if the file does not exist, as wanted or is not empty
[ -e /etc2/snmpd.conf ] && [ -z "$(cat /etc2/snmpd.conf)" ] && rm /etc2/snmpd.conf || :


#BNPROD-2222 Ensure that the login as root is possible
# This part is limited to all builds done before 495, as we might want to change this later
# So we should not forget this

# nok-20160208
# default for newer installations (we don't have the build number any longer
curBuildNumber=496
[[ -r /etc/build.txt ]] && [[ 0 -lt $(grep BuildNumber /etc/build.txt) ]] && {
	curBuildNumber=$(grep BuildNumber /etc/build.txt | sed -e 's/.*=//')
}

if [ ${curBuildNumber} -le 495 -a -e /etc2/sshd/sshd_config ]; then
	sed -i 's/\#PermitRootLogin yes/PermitRootLogin yes/' /etc2/sshd/sshd_config
fi


###
# Trigger the software update
###
updateImage=""
scriptFolder=""
if [ $# -ge 2 ]; then
	updateImage="$1"
	scriptFolder="$2"
else
	# Works only with the regular watch update script calls
	updateImage="$(ps x | grep update.sh | grep -v grep | awk '{printf $6}')"
	scriptFolder=$0
	scriptFolder=${scriptFolder%/*}
	pushd ${scriptFolder} > /dev/null
	scriptFolder=$PWD
	popd > /dev/null
fi

tar -xf "${updateImage}" -C "${scriptFolder}" "swUpdates"
pushd ${scriptFolder}
cd swUpdates
for i in *.sh ; do
	bash $i
done
popd

## BNPROD-3473 Getting ride of the old fixed ssh keys
## Simply check the sha1sum from one of them and delete it after the other.
## So in case that something went terribly wrong, the deletion of all keys
## still work as it should
if [ "$(sha1sum /etc2/sshd/ssh_host_rsa_key 2> /dev/null | awk '{printf $1}')" = 69852869bf0a399af58d0cde194a5bc817a66898 ] > /dev/null; then
	rm -rf /etc2/sshd/ssh_host_dsa* /etc2/sshd/ssh_host_key*
	rm -rf /etc2/sshd/ssh_host_rsa_key
fi

#BNPROD-3337 Correct the path definitions of existing ssh key definition
if [ -e "/etc2/sshd/sshd_config" ]; then
	# Remove the unused ssh protocol 1 version
	sed -i '/^# HostKey for protocol version 1/d' /etc2/sshd/sshd_config
	sed -i '/^HostKey .*ssh_host_key$/d' /etc2/sshd/sshd_config
	# Correct the path of the remaining keys, the linking should solve this, too
	sed -i 's%^HostKey /etc/%HostKey /etc2/%' /etc2/sshd/sshd_config
fi

# BNPROD-2788 /mnt/free/download is no longer necessary
# or wanted, so purge it, but only if it's empty.
# Since busybox rm can't handle -d, use rmdir and live with
# the error
rmdir /mnt/free/download 2>/dev/null || :

# Should always return 0 as nothing critical should fail above
exit 0
