#!/bin/bash
# ----------------------------------------------------------------------------
## @file  adminOwnMod.sh
## @brief fix ownership and access rights of the admin home directory
##
## Since V1.02.0x the home directory of user admin is owned by the wrong group
## bn2user.  We recursively change the group to the bn2admin group.
##
## While we're at it, we make sure the home directory as well as the .ssh
## directory have the correct access right bits set.
# ----------------------------------------------------------------------------

echo $0

readonly HOME_DIR=/etc2/home
readonly ADMIN_HOME=${HOME_DIR}/admin
readonly ADMIN_DSSH=${ADMIN_HOME}/.ssh

## the group identifier we are seeking
readonly BN2ADMIN=1000

# if the directory does not exist, there's nothing to do
[[ ! -d ${ADMIN_HOME} ]] && exit 0

[[ ${BN2ADMIN} -ne $(ls -gnd /home/admin | awk ' {printf("%d", $3)} ') ]] && {
	chgrp -R ${BN2ADMIN} ${ADMIN_HOME}
}

# restrict access.  Only members of the same group are allowed
chmod 0750 ${ADMIN_HOME}

# make sure the .ssh directory has the correct permissions
[[ -d ${ADMIN_DSSH} ]] && chmod 700 ${ADMIN_DSSH}

# ----------------------------------------------------------------------------
# adminOwnMod.sh ends here
