#!/bin/bash

## @file configStrings.sh
## @brief Create the Setup and Capability string, if they don't exist yet
##
## Check if there is no Setup and Cabality string present yet.
## If this is the case, the values are read from the ''CSV_FILE'', which
## contains those two values in the following layout:
## '''"$ARTICLE_NUMBER",$SETUP,$CAPABILITY'''
## Where ''$ARTICLE_NUMBER'' is used as identifier and ''$SETUP'' and
## ''$CAPABILITY'' define the values accordingly using one line per definition.



CSV_FILE="./BN2Strings.csv"

# if uboot variable ConfigGeneratorBypass is set and is true, exit 
if [ -n "$(fw_printenv ConfigGeneratorBypass 2> /dev/null)" ] && [ "$(fw_printenv ConfigGeneratorBypass 2> /dev/null | cut -d= -f2)" == "true" ]; then
	echo "ConfigGenerator will be bypassed"
	exit 0
fi

echo "# checking DevArtNr"
DEV_ART_NR="$(fw_printenv DevArtNr 2> /dev/null | cut -d= -f2)"
echo "DevArtNr = $DEV_ART_NR"
# Bypass all further checks for PowerUnits. Use inverted logic, to avoid exit on failure
[ "${DEV_ART_NR:0:5}" != "802.9" ] || exit 0
if [ -z "${DEV_ART_NR}" ] ; then
	echo "DevArtNr not in Uboot"
	if [ -z "$(fw_printenv Capability 2> /dev/null)" ] || [ -z "$(fw_printenv Setup 2> /dev/null)" ] || [ "$(fw_printenv Capability -n 2> /dev/null)" == "nc" ] || [ "$(fw_printenv Setup -n 2> /dev/null)" == "nc" ]; then
		echo "Neither configuration strings nor DevArtNr found in uboot"
		echo "exiting now, won't run"
		exit 1
	else
		echo "DevArtNr not found in uboot, using configuration strings from uboot"
		exit 0
	fi
fi

echo "# checking configuration strings"
if [ -n "$(fw_printenv Capability 2> /dev/null)" ] && [ -n "$(fw_printenv Setup 2> /dev/null)" ] && [ "$(fw_printenv Capability -n 2> /dev/null)" != "nc" ] && [ "$(fw_printenv Setup -n 2> /dev/null)" != "nc" ]; then
	echo "Uboot PDU configurations seem to be okay"
	exit 0
fi


echo "# checking csv"
if ! ( [ -f $CSV_FILE ] && [ -r $CSV_FILE  ] ) || ! grep -q "$DEV_ART_NR" $CSV_FILE ; then
	echo "DevArtNr not found in csv, Configuration strings not found in uboot"
	echo "giving up, wont run"
	exit 1
fi

echo "# get setup string and capability string from csv file"
SETUP=$(grep "${DEV_ART_NR}" ${CSV_FILE} | cut -d, -f2)
CAPABILITY=$(grep "${DEV_ART_NR}" ${CSV_FILE} | cut -d, -f3)

echo "# write strings into uboot"
fw_setenv Setup "${SETUP}"
fw_setenv Capability "${CAPABILITY}"

echo "# strings written"
