/**
 * Schema changes necessary to get from pdu_persistency V1.00.xx to V1.01.00
 */

-- stop on error
.bail ON

-- create a new table SocketGroup referencing sensorvariabledef instead of socketgroupdefinition

CREATE TABLE SocketGroupTmp (
	   socketID	INTEGER NOT NULL,
	   groupID	INTEGER NOT NULL,
	   PRIMARY KEY (socketID, groupID),
	   FOREIGN KEY (socketID) REFERENCES SensorVariableDef (sensorVariableID)
									  ON UPDATE RESTRICT
									  ON DELETE CASCADE,
	   FOREIGN KEY (groupID) REFERENCES SensorVariableDef (sensorVariableID)
									  ON UPDATE RESTRICT
									  ON DELETE CASCADE);

INSERT INTO SocketGroupTmp SELECT socketID, groupID FROM SocketGroup;

PRAGMA foreign_keys = OFF;

DROP TABLE SocketGroup;
ALTER TABLE SocketGroupTmp RENAME TO SocketGroup;

PRAGMA foreign_keys_check;
PRAGMA foreign_keys = ON;

-- drop table SocketGroupDefinition

DROP TABLE SocketGroupDefinition;


/* Remove the columns ledEnabled and syslogEnabled from table SignalChain */

CREATE TABLE SignalChainTmp (
		signalChainID    INTEGER NOT NULL PRIMARY KEY,
		signalChainName  TEXT,
		signalChainDesc  TEXT,
		acousticEnabled  INTEGER NOT NULL CHECK (acousticEnabled BETWEEN 0 AND 1),
		smtpEnabled      INTEGER NOT NULL CHECK (smtpEnabled BETWEEN 0 AND 1),
		displayEnabled   INTEGER NOT NULL CHECK (displayEnabled BETWEEN 0 AND 1),
		snmpEnabled      INTEGER NOT NULL CHECK (snmpEnabled BETWEEN 0 AND 1));

INSERT INTO SignalChainTmp
SELECT signalChainID, signalChainName, signalChainDesc, acousticEnabled, smtpEnabled, displayEnabled, snmpEnabled
FROM   SignalChain;

PRAGMA foreign_keys = OFF;

DROP TABLE SignalChain;
ALTER TABLE SignalChainTmp RENAME TO SignalChain;

PRAGMA foreign_keys_check;
PRAGMA foreign_keys = ON;


/* Remove the columns userSnmpv3*Local*Key from table User
 * Rename isActive to services
 * Add a description and a home field
 */

CREATE TABLE UserTmp (
		userID			INTEGER NOT NULL PRIMARY KEY,
		userName     	TEXT NOT NULL UNIQUE,
		userRealName 	TEXT NOT NULL DEFAULT '',
		userDescription TEXT NOT NULL DEFAULT '',
		userPasswd   	TEXT NOT NULL,
		userLanguage 	TEXT NOT NULL,
		userEmail    	TEXT NOT NULL DEFAULT '',
		userHome     	TEXT NOT NULL DEFAULT '',
		services     	INTEGER  DEFAULT 0,
		userSnmpv3AuthProtocol  INTEGER,
		userSnmpv3PrivProtocol  INTEGER,
		userSnmpv3MD5MasterAuthKey TEXT NOT NULL DEFAULT '',
		userSnmpv3SHAMasterAuthKey TEXT NOT NULL DEFAULT '',
		userSnmpv3MD5MasterPrivKey TEXT NOT NULL DEFAULT '',
		userSnmpv3SHAMasterPrivKey TEXT NOT NULL DEFAULT '',
		userSnmpv3Access INTEGER,
		userSnmpv3AccessControlList  TEXT NOT NULL DEFAULT '');

INSERT INTO UserTmp
SELECT userid, username, userrealname, '', userpasswd, userlanguage, useremail, '', isactive,
       userSnmpv3AuthProtocol, userSnmpv3PrivProtocol, userSnmpv3MD5MasterAuthKey, userSnmpv3SHAMasterAuthKey,
       userSnmpv3MD5MasterPrivKey, userSnmpv3SHAMasterPrivKey, userSnmpv3Access, userSnmpv3AccessControlList
FROM   User;

PRAGMA foreign_keys = OFF;

DROP TABLE User;
ALTER TABLE UserTmp RENAME TO User;

PRAGMA foreign_keys_check;
PRAGMA foreign_keys = ON;


/* Modify the log entry printed out for user-setting changes */

UPDATE EventLogModuleAction
SET    format = 'Settings for user "@USER@" edited: @KVP@'
WHERE  mid = 2 AND aid = 3;

UPDATE EventLogModuleAction
SET format = 'New session for user "@USER@"'
WHERE  mid = 1 AND aid = 4;

UPDATE EventLogModuleAction
SET format = 'User "@USER@" logged out'
WHERE  mid = 1 AND aid = 5;

UPDATE EventLogModuleAction
SET format = 'New user "@USER@" created'
WHERE  mid = 2 AND aid = 1;

UPDATE EventLogModuleAction
SET format = 'User "@USER@" deleted'
WHERE  mid = 2 AND aid = 2;

/* Don't implicitely remove a trapreceiver together with a user, instead restrict the operation */

PRAGMA foreign_keys = OFF;

CREATE TABLE SnmpTrapReceiverTmp (
		trapReceiverID  INTEGER	 NOT NULL PRIMARY KEY,
		trname			TEXT NOT NULL DEFAULT '',
		trdesc			TEXT NOT NULL DEFAULT '',
		ipAddress       TEXT NOT NULL DEFAULT '',
		isEnabled       INTEGER,
		snmpVersion     INTEGER,
		communityName   TEXT NOT NULL DEFAULT '',
		userID   		INTEGER,
		FOREIGN KEY (userID)	REFERENCES User (userID)
								ON UPDATE RESTRICT
								ON DELETE RESTRICT);

INSERT INTO SnmpTrapReceiverTmp
SELECT trapreceiverid, trname, trdesc, ipaddress, isenabled, snmpversion, communityname, userid
FROM   SnmpTrapReceiver;

DROP TABLE SnmpTrapReceiver;
ALTER TABLE SnmpTrapReceiverTmp RENAME TO SnmpTrapReceiver;

PRAGMA foreign_keys_check;
PRAGMA foreign_keys = ON;



-- ensure that the friendly names are all 40 characters or less
-- same for descriptions up to 255 characters

CREATE TABLE SensorNameTmp (
	   sensorVariableID	 INTEGER NOT NULL PRIMARY KEY,
	   variableName		 TEXT	 NOT NULL DEFAULT '',
	   variableFriendlyName	 TEXT	 NOT NULL DEFAULT '',
	   variableDescription	 TEXT	 NOT NULL DEFAULT '',
	   userDefined		 INTEGER DEFAULT 0,   -- translates into a boolean
	   FOREIGN KEY (sensorVariableID) REFERENCES SensorVariableDef (sensorVariableID)
									  ON UPDATE RESTRICT
									  ON DELETE CASCADE);
PRAGMA foreign_keys = OFF;

INSERT INTO SensorNameTmp
SELECT sensorvariableid, variablename, SUBSTR(variablefriendlyname, 1, 40), SUBSTR(variabledescription, 1, 255), userdefined
FROM SensorName;

DROP TABLE SensorName;
ALTER TABLE SensorNameTmp RENAME TO SensorName;

PRAGMA foreign_keys_check;
PRAGMA foreign_keys = ON;


/* The user_version defines the schema for our applications - this comes last */

PRAGMA user_version = 10100;
